@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.1.9 (http://editor.froala.com)
+ * froala_editor v1.2.1 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -28,6 +28,7 @@ $.Editable.LANGS['it'] = {
     "Heading 4": "Intestazione 4",
     "Heading 5": "Intestazione 5",
     "Heading 6": "Intestazione 6",
+    "Block Style": "Stile di blocco",
     "Alignment": "Allineamento",
     "Align Left": "Allinea a Sinistra",
     "Align Center": "Allinea al Cento",
@@ -53,6 +54,7 @@ $.Editable.LANGS['it'] = {
     "Insert image": "Inserisci Immagine",
     "Drop image": "Rilascia Immagine",
     "or click": "oppure fai click su",
+    "or": "o",
     "Enter URL": "Inserisci URL",
     "Please wait!": "Attendere prego!",
     "Are you sure? Image will be deleted.": "Sei sicuro? Immagine verr\u00e0 cancellata.",
