@@ -1,5 +1,5 @@
 /*!
- * froala_editor v1.1.9 (http://editor.froala.com)
+ * froala_editor v1.2.1 (http://editor.froala.com)
  * Copyright 2014-2014 Froala
  */
 
@@ -28,6 +28,7 @@ $.Editable.LANGS['pt_pt'] = {
     "Heading 4": "Cabe\u00e7alho 4",
     "Heading 5": "Cabe\u00e7alho 5",
     "Heading 6": "Cabe\u00e7alho 6",
+    "Block Style": "Estilo do bloco",
     "Alignment": "Alinhamento",
     "Align Left": "Alinhar \u00e0 esquerda",
     "Align Center": "Alinhar ao centro",
@@ -53,6 +54,7 @@ $.Editable.LANGS['pt_pt'] = {
     "Insert image": "Inserir imagem",
     "Drop image": "Largue imagem",
     "or click": "ou clique em",
+    "or": "ou",
     "Enter URL": "Digite a URL",
     "Please wait!": "Por favor, sagacidade!",
     "Are you sure? Image will be deleted.": "Voc\u00ea tem certeza? Imagem ser\u00e1 apagada.",
