@@ -1,6 +1,6 @@
 from django.views.decorators.csrf import csrf_exempt
 import json
-from django.http import HttpResponse
+from django.http import JsonResponse
 from django.conf import settings
 import uuid
 import os
@@ -30,4 +30,4 @@ def image_upload(request):
             fd.write(chunk)
         fd.close()
         link = '%s%s/%s' % (media_url, upload_to, file_name)
-        return HttpResponse(json.dumps({'link': link}), content_type="application/json")
+        return JsonResponse({'link': link})
