@@ -8,7 +8,9 @@ import json
 class FroalaEditor(widgets.Textarea):
     def __init__(self, *args, **kwargs):
         self.options = kwargs.pop('options', {})
-        self.plugins = kwargs.pop('plugins', {})
+        self.plugins = kwargs.pop('plugins', getattr(settings, 'FROALA_EDITOR_PLUGINS', (
+                                  'font_size', 'font_family', 'colors', 'block_styles', 'video', 'tables', 'media_manager', 'lists', 'file_upload'
+                                  )))
         self.theme = kwargs.pop('theme', None)
         self.include_jquery = kwargs.pop('include_jquery', True)
         self.image_upload = kwargs.pop('image_upload', True)
@@ -27,7 +29,10 @@ class FroalaEditor(widgets.Textarea):
         except NoReverseMatch:
             default_options['imageUpload'] = False
         settings_options = getattr(settings, 'FROALA_EDITOR_OPTIONS', {})
-        options = dict(default_options.items() + settings_options.items() + self.options.items())
+        # options = dict(default_options.items() + settings_options.items() + self.options.items())
+        options = dict(default_options.items()).copy()
+        options.update(settings_options.items())
+        options.update(self.options.items())
 
         if self.theme:
             options['theme'] = self.theme
@@ -57,8 +62,7 @@ class FroalaEditor(widgets.Textarea):
         js = ('froala_editor/js/froala_editor.min.js',)
 
         if self.include_jquery:
-            print self.include_jquery
-            js = ('froala_editor/js/libs/jquery-1.10.2.min.js',) + js
+            js = ('froala_editor/js/libs/jquery-1.11.1.min.js',) + js
 
         if self.theme:
             css['all'] += ('froala_editor/css/themes/'+self.theme+'.css',)
